@@ -47,16 +47,24 @@ sub run {
     $self->setup_listener();
     if ($self->{max_workers} != 0) {
         # use Parallel::Prefork
-        my $pm = Parallel::Prefork->new({
+        my %pm_args = (
             max_workers => $self->{max_workers},
             trap_signals => {
                 TERM => 'TERM',
                 HUP  => 'TERM',
             },
-        });
-        while ($pm->signal_received ne 'TERM') {
+        );
+        if (defined $self->{spawn_interval}) {
+            $pm_args{trap_signals}{USR1} = [ 'TERM', $self->{spawn_interval} ];
+            $pm_args{spawn_interval} = $self->{spawn_interval};
+        }
+        if (defined $self->{err_respawn_interval}) {
+            $pm_args{err_respawn_interval} = $self->{err_respawn_interval};
+        }
+        my $pm = Parallel::Prefork->new(\%pm_args);
+        while ($pm->signal_received !~ /^(TERM|USR1)$/) {
             $pm->start and next;
-            $self->accept_loop($app, $self->{max_reqs_per_child});
+            $self->accept_loop($app, $self->_calc_reqs_per_child());
             $pm->finish;
         }
         $pm->wait_all_children;
@@ -64,9 +72,20 @@ sub run {
         # run directly, mainly for debugging
         local $SIG{TERM} = sub { exit 0; };
         while (1) {
-            $self->accept_loop($app, $self->{max_reqs_per_child});
+            $self->accept_loop($app, $self->_calc_reqs_per_child());
         }
     }
 }
 
+sub _calc_reqs_per_child {
+    my $self = shift;
+    my $max = $self->{max_reqs_per_child};
+    if (my $min = $self->{min_reqs_per_child}) {
+        srand((rand() * 2 ** 30) ^ $$ ^ time);
+        return $max - int(($max - $min + 1) * rand);
+    } else {
+        return $max;
+    }
+}
+
 1;
